@@ -55,6 +55,7 @@ OC.L10N.register(
     "Update" : "Actualizar",
     "Location" : "Ubicación",
     "Description" : "Descripción",
+    "Visibility" : "Visibilidad",
     "to" : "para",
     "Add" : "Añadir",
     "Monday" : "Lunes",
@@ -77,24 +78,26 @@ OC.L10N.register(
     "Delete file" : "Borrar archivo",
     "Available" : "Disponible",
     "Not available" : "No disponible",
-    "Unknown" : "Desconocido",
+    "Legend" : "Leyenda",
     "Done" : "Terminado",
+    "Unknown" : "Desconocido",
     "Accept" : "Aceptar",
     "Decline" : "Declinar",
     "Tentative" : "Tentativo",
     "Attendees" : "Asistentes",
-    "All day" : "Todo el día",
+    "Remove group" : "Eliminar grupo",
     "Repeat" : "Repetir",
     "never" : "nunca",
     "after" : "después",
     "first" : "primero",
+    "Resources" : "Recursos",
     "available" : "disponible",
     "Global" : "Global",
     "Subscribe" : "Suscribirse",
     "Select a date" : "Elija una fecha",
     "Personal" : "Personal",
-    "Details" : "Detalles",
-    "Resources" : "Recursos",
+    "Edit event" : "Editar evento",
+    "All day" : "Todo el día",
     "Close" : "Cerrar",
     "Anniversary" : "Aniversario",
     "Week {number} of {year}" : "Semana {number} de {year}",
@@ -108,6 +111,7 @@ OC.L10N.register(
     "When shared hide this event" : "Al compartir, ocultar este evento ",
     "Status" : "Estatus",
     "Confirmed" : "Confirmado",
-    "Categories" : "Categoría"
+    "Categories" : "Categoría",
+    "Details" : "Detalles"
 },
 "nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
