@@ -260,7 +260,6 @@ OC.L10N.register(
     "Book appointment" : "Reservar cita",
     "on" : "el",
     "at" : "a las",
-    "Reminder" : "Recordatorio",
     "before at" : "antes de las",
     "Notification" : "Notificación",
     "Email" : "Correo electrónico",
@@ -271,7 +270,6 @@ OC.L10N.register(
     "Edit time" : "Editar hora",
     "Save time" : "Guardar hora",
     "Remove reminder" : "Eliminar recordatorio",
-    "+ Add reminder" : "+ Añadir recordatorio",
     "Add reminder" : "Añadir recordatorio",
     "seconds" : "segundos",
     "minutes" : "minutos",
@@ -302,26 +300,25 @@ OC.L10N.register(
     "Awaiting response" : "Esperando respuesta",
     "Checking availability" : "Comprobando disponibilidad",
     "Has not responded to {organizerName}'s invitation yet" : "No ha respondido a la invitación de {organizerName} aún",
-    "Select automatic slot" : "Seleccionar un espacio de tiempo automáticamente",
     "chairperson" : "presidente",
     "required participant" : "participante requerido",
     "non-participant" : "no participante",
     "optional participant" : "participante opcional",
     "{organizer} (organizer)" : "{organizer} (organizador)",
     "{attendee} ({role})" : "{attendee} ({role})",
-    "Free" : "Disponible",
-    "Busy (tentative)" : "Ocupado (tentativo)",
-    "Busy" : "Ocupado",
-    "Out of office" : "Fuera de la oficina",
-    "Unknown" : "Desconocido",
     "Availability of attendees, resources and rooms" : "Disponibilidad de asistentes, recursos y salas",
-    "with" : "con",
-    "Available times:" : "Horarios disponibles:",
     "Suggestion accepted" : "Sugerencia aceptada",
+    "Legend" : "Leyenda",
+    "Out of office" : "Fuera de la oficina",
+    "Attendees:" : "Asistentes:",
     "Done" : "Terminado",
     "Search room" : "Buscar sala",
     "Room name" : "Nombre del cuarto",
     "Check room availability" : "Comprobar la disponibilidad de salas",
+    "Free" : "Disponible",
+    "Busy (tentative)" : "Ocupado (tentativo)",
+    "Busy" : "Ocupado",
+    "Unknown" : "Desconocido",
     "Find a time" : "Buscar una hora",
     "The invitation has been accepted successfully." : "Invitación aceptada exitosamente.",
     "Failed to accept the invitation." : "No se pudo aceptar la invitación.",
@@ -358,7 +355,6 @@ OC.L10N.register(
     "Cannot modify all-day setting for events that are part of a recurrence-set." : "No se puede modificar la configuración de todo el día para eventos que forman parte de una serie recurrente.",
     "From" : "De",
     "To" : "Para",
-    "All day" : "Todo el día",
     "Repeat" : "Repetir",
     "_time_::_times_" : ["vez","veces","veces"],
     "never" : "nunca",
@@ -381,7 +377,7 @@ OC.L10N.register(
     "Does not repeat" : "No se repite",
     "The recurrence definition of this event is not fully supported by Nextcloud. If you edit the recurrence-options, certain recurrences may be lost." : "La definición de recurrencia de este evento no está completamente soportada por Nextcloud. Si edita las opciones de recurrencia, es posible que se pierdan ciertas ocurrencias.",
     "No rooms or resources yet" : "Aún no hay salas ni recursos",
-    "Suggestions" : "Sugerencias",
+    "Resources" : "Recursos",
     "_{seatingCapacity} seat_::_{seatingCapacity} seats_" : ["{seatingCapacity} asiento","{seatingCapacity} asientos","{seatingCapacity} asientos"],
     "Add resource" : "Añadir recurso",
     "Has a projector" : "Tiene un proyector",
@@ -425,7 +421,6 @@ OC.L10N.register(
     "No valid public calendars configured" : "No hay calendarios públicos válidos configurados",
     "Speak to the server administrator to resolve this issue." : "Comuníquese con el administrador del servidor para resolver este problema.",
     "Public holiday calendars are provided by Thunderbird. Calendar data will be downloaded from {website}" : "Los calendarios públicos de días feriados son proporcionados por Thunderbird. Los datos del calendario se descargarán desde {website}",
-    "These public calendars are suggested by the sever administrator. Calendar data will be downloaded from the respective website." : "Estos calendarios públicos son sugeridos por el administrador del servidor. Los datos del calendario se descargarán desde el sitio web correspondiente.",
     "By {authors}" : "Por {authors}",
     "Subscribed" : "Suscrito",
     "Subscribe" : "Suscríbete",
@@ -447,15 +442,15 @@ OC.L10N.register(
     "Personal" : "Personal",
     "The automatic time zone detection determined your time zone to be UTC.\nThis is most likely the result of security measures of your web browser.\nPlease set your time zone manually in the calendar settings." : "La detección automática de la zona horaria determinó que su zona horaria sea UTC.\nLo más probable es que sea el resultado de las medidas de seguridad de su navegador web.\nPor favor, establezca su zona horaria manualmente en la configuración del calendario. ",
     "Your configured time zone ({timezoneId}) was not found. Falling back to UTC.\nPlease change your time zone in the settings and report this issue." : "No se encontró la zona horaria configurada ({timezoneId}). Volviendo a UTC.\nPor favor, cambie su zona horaria en la configuración e informe de este problema.",
+    "Edit event" : "Editar evento",
     "Event does not exist" : "El evento no existe",
     "Duplicate" : "Duplicado",
     "Delete this occurrence" : "Eliminar esta ocurrencia",
     "Delete this and all future" : "Eliminar ésta y las futuras",
-    "Details" : "Detalles",
+    "All day" : "Todo el día",
     "Managing shared access" : "Administrando el acceso compartido",
     "Deny access" : "Denegar acceso",
     "Invite" : "Invitar",
-    "Resources" : "Recursos",
     "_User requires access to your file_::_Users require access to your file_" : ["El usuario requiere acceso a su archivo","Los usuarios requieren acceso a su archivo","Los usuarios requieren acceso a su archivo"],
     "_Attachment requires shared access_::_Attachments requiring shared access_" : ["Adjunto que requiere acceso compartido","Adjuntos que requieren acceso compartido","Adjuntos que requieren acceso compartido"],
     "Untitled event" : "Evento sin título",
@@ -551,6 +546,13 @@ OC.L10N.register(
     "This is an event reminder." : "Esto es un recordatorio del evento.",
     "Error while parsing a PROPFIND error" : "Error al analizar un error PROPFIND",
     "Appointment not found" : "Cita no encontrada",
-    "User not found" : "No se encontró el usuario"
+    "User not found" : "No se encontró el usuario",
+    "Reminder" : "Recordatorio",
+    "+ Add reminder" : "+ Añadir recordatorio",
+    "Select automatic slot" : "Seleccionar un espacio de tiempo automáticamente",
+    "with" : "con",
+    "Available times:" : "Horarios disponibles:",
+    "Suggestions" : "Sugerencias",
+    "Details" : "Detalles"
 },
 "nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
